# coding: utf-8

"""
    candidates-api

    The Candidate APIs allows you to add, update and delete candidates.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phenom.commons.api_client import ApiClient


class CandidatesApi(object):
    base_path = "/candidates-api"  # your base path

    def __init__(self, token, gateway_url, apikey, api_client=None):
        if api_client is None:
            api_client = ApiClient(gateway_url + self.base_path, apikey, token)
        self.api_client = api_client

    def create_candidate(self, body, x_ph_user_id, **kwargs):  # noqa: E501
        """Create Candidate  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_candidate(body, x_ph_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateCandidateRequest body: Candidate profile created successfully (required)
        :param str x_ph_user_id: (required)
        :return: CandidateCreateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_candidate_with_http_info(body, x_ph_user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.create_candidate_with_http_info(body, x_ph_user_id, **kwargs)  # noqa: E501
            return data

    def create_candidate_with_http_info(self, body, x_ph_user_id, **kwargs):  # noqa: E501
        """Create Candidate  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_candidate_with_http_info(body, x_ph_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateCandidateRequest body: Candidate profile created successfully (required)
        :param str x_ph_user_id: (required)
        :return: CandidateCreateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_ph_user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_candidate" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_candidate`")  # noqa: E501
        # verify the required parameter 'x_ph_user_id' is set
        if ('x_ph_user_id' not in params or
                params['x_ph_user_id'] is None):
            raise ValueError("Missing the required parameter `x_ph_user_id` when calling `create_candidate`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_ph_user_id' in params:
            header_params['x-ph-userId'] = params['x_ph_user_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CandidateCreateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_candidate_profile(self, candidate_id, x_ph_user_id, **kwargs):  # noqa: E501
        """Delete Candidate  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_candidate_profile(candidate_id, x_ph_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: Id of the candidate (required)
        :param str x_ph_user_id: (required)
        :return: CandidateDetailsUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_candidate_profile_with_http_info(candidate_id, x_ph_user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_candidate_profile_with_http_info(candidate_id, x_ph_user_id, **kwargs)  # noqa: E501
            return data

    def delete_candidate_profile_with_http_info(self, candidate_id, x_ph_user_id, **kwargs):  # noqa: E501
        """Delete Candidate  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_candidate_profile_with_http_info(candidate_id, x_ph_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: Id of the candidate (required)
        :param str x_ph_user_id: (required)
        :return: CandidateDetailsUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['candidate_id', 'x_ph_user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_candidate_profile" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `delete_candidate_profile`")  # noqa: E501
        # verify the required parameter 'x_ph_user_id' is set
        if ('x_ph_user_id' not in params or
                params['x_ph_user_id'] is None):
            raise ValueError("Missing the required parameter `x_ph_user_id` when calling `delete_candidate_profile`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_user_id' in params:
            header_params['x-ph-userId'] = params['x_ph_user_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CandidateDetailsUpdateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_candidate(self, x_ph_user_id, **kwargs):  # noqa: E501
        """Get Candidate  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_candidate(x_ph_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_ph_user_id: (required)
        :param str candidate_id:
        :param str email:
        :param str ats_id:
        :param str linked_in_profile_url:
        :return: Candidate
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_candidate_with_http_info(x_ph_user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_candidate_with_http_info(x_ph_user_id, **kwargs)  # noqa: E501
            return data

    def get_candidate_with_http_info(self, x_ph_user_id, **kwargs):  # noqa: E501
        """Get Candidate  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_candidate_with_http_info(x_ph_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_ph_user_id: (required)
        :param str candidate_id:
        :param str email:
        :param str ats_id:
        :param str linked_in_profile_url:
        :return: Candidate
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_ph_user_id', 'candidate_id', 'email', 'ats_id', 'linked_in_profile_url']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_candidate" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_ph_user_id' is set
        if ('x_ph_user_id' not in params or
                params['x_ph_user_id'] is None):
            raise ValueError("Missing the required parameter `x_ph_user_id` when calling `get_candidate`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'candidate_id' in params:
            query_params.append(('candidateId', params['candidate_id']))  # noqa: E501
        if 'email' in params:
            query_params.append(('email', params['email']))  # noqa: E501
        if 'ats_id' in params:
            query_params.append(('atsId', params['ats_id']))  # noqa: E501
        if 'linked_in_profile_url' in params:
            query_params.append(('linkedInProfileUrl', params['linked_in_profile_url']))  # noqa: E501

        header_params = {}
        if 'x_ph_user_id' in params:
            header_params['x-ph-userId'] = params['x_ph_user_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Candidate',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_candidate_address(self, candidate_id, x_ph_user_id, **kwargs):  # noqa: E501
        """Get Address  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_candidate_address(candidate_id, x_ph_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: Id of the candidate (required)
        :param str x_ph_user_id: (required)
        :return: Address
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_candidate_address_with_http_info(candidate_id, x_ph_user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_candidate_address_with_http_info(candidate_id, x_ph_user_id, **kwargs)  # noqa: E501
            return data

    def get_candidate_address_with_http_info(self, candidate_id, x_ph_user_id, **kwargs):  # noqa: E501
        """Get Address  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_candidate_address_with_http_info(candidate_id, x_ph_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: Id of the candidate (required)
        :param str x_ph_user_id: (required)
        :return: Address
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['candidate_id', 'x_ph_user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_candidate_address" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `get_candidate_address`")  # noqa: E501
        # verify the required parameter 'x_ph_user_id' is set
        if ('x_ph_user_id' not in params or
                params['x_ph_user_id'] is None):
            raise ValueError("Missing the required parameter `x_ph_user_id` when calling `get_candidate_address`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_user_id' in params:
            header_params['x-ph-userId'] = params['x_ph_user_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/address', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Address',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_candidate_awards(self, candidate_id, x_ph_user_id, **kwargs):  # noqa: E501
        """Get Awards  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_candidate_awards(candidate_id, x_ph_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: Id of the candidate (required)
        :param str x_ph_user_id: (required)
        :return: Award
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_candidate_awards_with_http_info(candidate_id, x_ph_user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_candidate_awards_with_http_info(candidate_id, x_ph_user_id, **kwargs)  # noqa: E501
            return data

    def get_candidate_awards_with_http_info(self, candidate_id, x_ph_user_id, **kwargs):  # noqa: E501
        """Get Awards  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_candidate_awards_with_http_info(candidate_id, x_ph_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: Id of the candidate (required)
        :param str x_ph_user_id: (required)
        :return: Award
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['candidate_id', 'x_ph_user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_candidate_awards" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `get_candidate_awards`")  # noqa: E501
        # verify the required parameter 'x_ph_user_id' is set
        if ('x_ph_user_id' not in params or
                params['x_ph_user_id'] is None):
            raise ValueError("Missing the required parameter `x_ph_user_id` when calling `get_candidate_awards`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_user_id' in params:
            header_params['x-ph-userId'] = params['x_ph_user_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/awards', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Award',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_candidate_certifications(self, candidate_id, x_ph_user_id, **kwargs):  # noqa: E501
        """Get Certifications  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_candidate_certifications(candidate_id, x_ph_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: Id of the candidate (required)
        :param str x_ph_user_id: (required)
        :return: Certification
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_candidate_certifications_with_http_info(candidate_id, x_ph_user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_candidate_certifications_with_http_info(candidate_id, x_ph_user_id, **kwargs)  # noqa: E501
            return data

    def get_candidate_certifications_with_http_info(self, candidate_id, x_ph_user_id, **kwargs):  # noqa: E501
        """Get Certifications  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_candidate_certifications_with_http_info(candidate_id, x_ph_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: Id of the candidate (required)
        :param str x_ph_user_id: (required)
        :return: Certification
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['candidate_id', 'x_ph_user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_candidate_certifications" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `get_candidate_certifications`")  # noqa: E501
        # verify the required parameter 'x_ph_user_id' is set
        if ('x_ph_user_id' not in params or
                params['x_ph_user_id'] is None):
            raise ValueError("Missing the required parameter `x_ph_user_id` when calling `get_candidate_certifications`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_user_id' in params:
            header_params['x-ph-userId'] = params['x_ph_user_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/certifications', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Certification',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_candidate_education(self, candidate_id, x_ph_user_id, **kwargs):  # noqa: E501
        """Get Education  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_candidate_education(candidate_id, x_ph_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: Id of the candidate (required)
        :param str x_ph_user_id: (required)
        :return: Education
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_candidate_education_with_http_info(candidate_id, x_ph_user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_candidate_education_with_http_info(candidate_id, x_ph_user_id, **kwargs)  # noqa: E501
            return data

    def get_candidate_education_with_http_info(self, candidate_id, x_ph_user_id, **kwargs):  # noqa: E501
        """Get Education  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_candidate_education_with_http_info(candidate_id, x_ph_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: Id of the candidate (required)
        :param str x_ph_user_id: (required)
        :return: Education
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['candidate_id', 'x_ph_user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_candidate_education" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `get_candidate_education`")  # noqa: E501
        # verify the required parameter 'x_ph_user_id' is set
        if ('x_ph_user_id' not in params or
                params['x_ph_user_id'] is None):
            raise ValueError("Missing the required parameter `x_ph_user_id` when calling `get_candidate_education`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_user_id' in params:
            header_params['x-ph-userId'] = params['x_ph_user_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/educations', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Education',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_candidate_experience(self, candidate_id, x_ph_user_id, **kwargs):  # noqa: E501
        """Get Experience  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_candidate_experience(candidate_id, x_ph_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: Id of the candidate (required)
        :param str x_ph_user_id: (required)
        :return: Experience
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_candidate_experience_with_http_info(candidate_id, x_ph_user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_candidate_experience_with_http_info(candidate_id, x_ph_user_id, **kwargs)  # noqa: E501
            return data

    def get_candidate_experience_with_http_info(self, candidate_id, x_ph_user_id, **kwargs):  # noqa: E501
        """Get Experience  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_candidate_experience_with_http_info(candidate_id, x_ph_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: Id of the candidate (required)
        :param str x_ph_user_id: (required)
        :return: Experience
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['candidate_id', 'x_ph_user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_candidate_experience" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `get_candidate_experience`")  # noqa: E501
        # verify the required parameter 'x_ph_user_id' is set
        if ('x_ph_user_id' not in params or
                params['x_ph_user_id'] is None):
            raise ValueError("Missing the required parameter `x_ph_user_id` when calling `get_candidate_experience`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_user_id' in params:
            header_params['x-ph-userId'] = params['x_ph_user_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/experiences', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Experience',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_candidate_preferred_locations(self, candidate_id, x_ph_userid, **kwargs):  # noqa: E501
        """Get Preferred Locations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_candidate_preferred_locations(candidate_id, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: Id of the candidate (required)
        :param str x_ph_userid: (required)
        :return: PreferredLocation
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_candidate_preferred_locations_with_http_info(candidate_id, x_ph_userid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_candidate_preferred_locations_with_http_info(candidate_id, x_ph_userid, **kwargs)  # noqa: E501
            return data

    def get_candidate_preferred_locations_with_http_info(self, candidate_id, x_ph_userid, **kwargs):  # noqa: E501
        """Get Preferred Locations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_candidate_preferred_locations_with_http_info(candidate_id, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: Id of the candidate (required)
        :param str x_ph_userid: (required)
        :return: PreferredLocation
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['candidate_id', 'x_ph_userid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_candidate_preferred_locations" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `get_candidate_preferred_locations`")  # noqa: E501
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `get_candidate_preferred_locations`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/preferred-locations', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PreferredLocation',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_candidate_recommendations(self, candidate_id, x_ph_user_id, **kwargs):  # noqa: E501
        """Get Recommendations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_candidate_recommendations(candidate_id, x_ph_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: Id of the candidate (required)
        :param str x_ph_user_id: (required)
        :return: Recommendations
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_candidate_recommendations_with_http_info(candidate_id, x_ph_user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_candidate_recommendations_with_http_info(candidate_id, x_ph_user_id, **kwargs)  # noqa: E501
            return data

    def get_candidate_recommendations_with_http_info(self, candidate_id, x_ph_user_id, **kwargs):  # noqa: E501
        """Get Recommendations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_candidate_recommendations_with_http_info(candidate_id, x_ph_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: Id of the candidate (required)
        :param str x_ph_user_id: (required)
        :return: Recommendations
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['candidate_id', 'x_ph_user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_candidate_recommendations" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `get_candidate_recommendations`")  # noqa: E501
        # verify the required parameter 'x_ph_user_id' is set
        if ('x_ph_user_id' not in params or
                params['x_ph_user_id'] is None):
            raise ValueError("Missing the required parameter `x_ph_user_id` when calling `get_candidate_recommendations`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_user_id' in params:
            header_params['x-ph-userId'] = params['x_ph_user_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/recommendations', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Recommendations',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_candidate_skills(self, candidate_id, x_ph_user_id, **kwargs):  # noqa: E501
        """Get Skills  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_candidate_skills(candidate_id, x_ph_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: Id of the candidate (required)
        :param str x_ph_user_id: (required)
        :return: Skills
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_candidate_skills_with_http_info(candidate_id, x_ph_user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_candidate_skills_with_http_info(candidate_id, x_ph_user_id, **kwargs)  # noqa: E501
            return data

    def get_candidate_skills_with_http_info(self, candidate_id, x_ph_user_id, **kwargs):  # noqa: E501
        """Get Skills  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_candidate_skills_with_http_info(candidate_id, x_ph_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: Id of the candidate (required)
        :param str x_ph_user_id: (required)
        :return: Skills
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['candidate_id', 'x_ph_user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_candidate_skills" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `get_candidate_skills`")  # noqa: E501
        # verify the required parameter 'x_ph_user_id' is set
        if ('x_ph_user_id' not in params or
                params['x_ph_user_id'] is None):
            raise ValueError("Missing the required parameter `x_ph_user_id` when calling `get_candidate_skills`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_user_id' in params:
            header_params['x-ph-userId'] = params['x_ph_user_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/skills', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Skills',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_tenant_specific_additional_fields(self, candidate_id, x_ph_user_id, **kwargs):  # noqa: E501
        """Get Additional Fields  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_tenant_specific_additional_fields(candidate_id, x_ph_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: Id of the candidate (required)
        :param str x_ph_user_id: (required)
        :return: AdditionalFields
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_tenant_specific_additional_fields_with_http_info(candidate_id, x_ph_user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_tenant_specific_additional_fields_with_http_info(candidate_id, x_ph_user_id, **kwargs)  # noqa: E501
            return data

    def get_tenant_specific_additional_fields_with_http_info(self, candidate_id, x_ph_user_id, **kwargs):  # noqa: E501
        """Get Additional Fields  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_tenant_specific_additional_fields_with_http_info(candidate_id, x_ph_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: Id of the candidate (required)
        :param str x_ph_user_id: (required)
        :return: AdditionalFields
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['candidate_id', 'x_ph_user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_tenant_specific_additional_fields" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `get_tenant_specific_additional_fields`")  # noqa: E501
        # verify the required parameter 'x_ph_user_id' is set
        if ('x_ph_user_id' not in params or
                params['x_ph_user_id'] is None):
            raise ValueError("Missing the required parameter `x_ph_user_id` when calling `get_tenant_specific_additional_fields`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_user_id' in params:
            header_params['x-ph-userId'] = params['x_ph_user_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/additional-fields', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AdditionalFields',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_candidate_address(self, body, x_ph_user_id, candidate_id, **kwargs):  # noqa: E501
        """Update address  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_candidate_address(body, x_ph_user_id, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateAddressRequest body: Update address of candidate (required)
        :param str x_ph_user_id: (required)
        :param str candidate_id: Id of the candidate (required)
        :return: AddressUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_candidate_address_with_http_info(body, x_ph_user_id, candidate_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_candidate_address_with_http_info(body, x_ph_user_id, candidate_id, **kwargs)  # noqa: E501
            return data

    def update_candidate_address_with_http_info(self, body, x_ph_user_id, candidate_id, **kwargs):  # noqa: E501
        """Update address  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_candidate_address_with_http_info(body, x_ph_user_id, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateAddressRequest body: Update address of candidate (required)
        :param str x_ph_user_id: (required)
        :param str candidate_id: Id of the candidate (required)
        :return: AddressUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_ph_user_id', 'candidate_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_candidate_address" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_candidate_address`")  # noqa: E501
        # verify the required parameter 'x_ph_user_id' is set
        if ('x_ph_user_id' not in params or
                params['x_ph_user_id'] is None):
            raise ValueError("Missing the required parameter `x_ph_user_id` when calling `update_candidate_address`")  # noqa: E501
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `update_candidate_address`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_user_id' in params:
            header_params['x-ph-userId'] = params['x_ph_user_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/address', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AddressUpdateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_candidate_awards(self, body, x_ph_user_id, candidate_id, **kwargs):  # noqa: E501
        """Update Awards  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_candidate_awards(body, x_ph_user_id, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateAwardsRequest body: Add/update awards of a candidate (required)
        :param str x_ph_user_id: (required)
        :param str candidate_id: Id of the candidate (required)
        :return: Award
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_candidate_awards_with_http_info(body, x_ph_user_id, candidate_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_candidate_awards_with_http_info(body, x_ph_user_id, candidate_id, **kwargs)  # noqa: E501
            return data

    def update_candidate_awards_with_http_info(self, body, x_ph_user_id, candidate_id, **kwargs):  # noqa: E501
        """Update Awards  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_candidate_awards_with_http_info(body, x_ph_user_id, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateAwardsRequest body: Add/update awards of a candidate (required)
        :param str x_ph_user_id: (required)
        :param str candidate_id: Id of the candidate (required)
        :return: Award
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_ph_user_id', 'candidate_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_candidate_awards" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_candidate_awards`")  # noqa: E501
        # verify the required parameter 'x_ph_user_id' is set
        if ('x_ph_user_id' not in params or
                params['x_ph_user_id'] is None):
            raise ValueError("Missing the required parameter `x_ph_user_id` when calling `update_candidate_awards`")  # noqa: E501
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `update_candidate_awards`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_user_id' in params:
            header_params['x-ph-userId'] = params['x_ph_user_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/awards', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Award',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_candidate_certifications(self, body, x_ph_user_id, candidate_id, **kwargs):  # noqa: E501
        """Update Certifications  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_candidate_certifications(body, x_ph_user_id, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateCertificationRequest body: Add/update certifications of a candidate (required)
        :param str x_ph_user_id: (required)
        :param str candidate_id: Id of the candidate (required)
        :return: CandidateDetailsUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_candidate_certifications_with_http_info(body, x_ph_user_id, candidate_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_candidate_certifications_with_http_info(body, x_ph_user_id, candidate_id, **kwargs)  # noqa: E501
            return data

    def update_candidate_certifications_with_http_info(self, body, x_ph_user_id, candidate_id, **kwargs):  # noqa: E501
        """Update Certifications  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_candidate_certifications_with_http_info(body, x_ph_user_id, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateCertificationRequest body: Add/update certifications of a candidate (required)
        :param str x_ph_user_id: (required)
        :param str candidate_id: Id of the candidate (required)
        :return: CandidateDetailsUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_ph_user_id', 'candidate_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_candidate_certifications" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_candidate_certifications`")  # noqa: E501
        # verify the required parameter 'x_ph_user_id' is set
        if ('x_ph_user_id' not in params or
                params['x_ph_user_id'] is None):
            raise ValueError("Missing the required parameter `x_ph_user_id` when calling `update_candidate_certifications`")  # noqa: E501
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `update_candidate_certifications`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_user_id' in params:
            header_params['x-ph-userId'] = params['x_ph_user_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/certifications', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CandidateDetailsUpdateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_candidate_education(self, body, x_ph_user_id, candidate_id, **kwargs):  # noqa: E501
        """Update Education  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_candidate_education(body, x_ph_user_id, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddOrUpdateEducationRequest body: Add/update education of a candidate (required)
        :param str x_ph_user_id: (required)
        :param str candidate_id: Id of the candidate (required)
        :return: CandidateDetailsUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_candidate_education_with_http_info(body, x_ph_user_id, candidate_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_candidate_education_with_http_info(body, x_ph_user_id, candidate_id, **kwargs)  # noqa: E501
            return data

    def update_candidate_education_with_http_info(self, body, x_ph_user_id, candidate_id, **kwargs):  # noqa: E501
        """Update Education  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_candidate_education_with_http_info(body, x_ph_user_id, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddOrUpdateEducationRequest body: Add/update education of a candidate (required)
        :param str x_ph_user_id: (required)
        :param str candidate_id: Id of the candidate (required)
        :return: CandidateDetailsUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_ph_user_id', 'candidate_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_candidate_education" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_candidate_education`")  # noqa: E501
        # verify the required parameter 'x_ph_user_id' is set
        if ('x_ph_user_id' not in params or
                params['x_ph_user_id'] is None):
            raise ValueError("Missing the required parameter `x_ph_user_id` when calling `update_candidate_education`")  # noqa: E501
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `update_candidate_education`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_user_id' in params:
            header_params['x-ph-userId'] = params['x_ph_user_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/educations', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CandidateDetailsUpdateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_candidate_experience(self, body, x_ph_user_id, candidate_id, **kwargs):  # noqa: E501
        """Update Experience  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_candidate_experience(body, x_ph_user_id, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddOrUpdateExperienceRequest body: Add/update experiences of a candidate. (required)
        :param str x_ph_user_id: (required)
        :param str candidate_id: Id of the candidate (required)
        :return: CandidateDetailsUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_candidate_experience_with_http_info(body, x_ph_user_id, candidate_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_candidate_experience_with_http_info(body, x_ph_user_id, candidate_id, **kwargs)  # noqa: E501
            return data

    def update_candidate_experience_with_http_info(self, body, x_ph_user_id, candidate_id, **kwargs):  # noqa: E501
        """Update Experience  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_candidate_experience_with_http_info(body, x_ph_user_id, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddOrUpdateExperienceRequest body: Add/update experiences of a candidate. (required)
        :param str x_ph_user_id: (required)
        :param str candidate_id: Id of the candidate (required)
        :return: CandidateDetailsUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_ph_user_id', 'candidate_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_candidate_experience" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_candidate_experience`")  # noqa: E501
        # verify the required parameter 'x_ph_user_id' is set
        if ('x_ph_user_id' not in params or
                params['x_ph_user_id'] is None):
            raise ValueError("Missing the required parameter `x_ph_user_id` when calling `update_candidate_experience`")  # noqa: E501
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `update_candidate_experience`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_user_id' in params:
            header_params['x-ph-userId'] = params['x_ph_user_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/experiences', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CandidateDetailsUpdateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_candidate_preferred_locations(self, body, x_ph_user_id, candidate_id, **kwargs):  # noqa: E501
        """Update Preferred Locations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_candidate_preferred_locations(body, x_ph_user_id, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdatePreferredLocationRequest body: update preferred locations on candidate profile (required)
        :param str x_ph_user_id: (required)
        :param str candidate_id: Id of the candidate (required)
        :return: PreferredLocationUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_candidate_preferred_locations_with_http_info(body, x_ph_user_id, candidate_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_candidate_preferred_locations_with_http_info(body, x_ph_user_id, candidate_id, **kwargs)  # noqa: E501
            return data

    def update_candidate_preferred_locations_with_http_info(self, body, x_ph_user_id, candidate_id, **kwargs):  # noqa: E501
        """Update Preferred Locations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_candidate_preferred_locations_with_http_info(body, x_ph_user_id, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdatePreferredLocationRequest body: update preferred locations on candidate profile (required)
        :param str x_ph_user_id: (required)
        :param str candidate_id: Id of the candidate (required)
        :return: PreferredLocationUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_ph_user_id', 'candidate_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_candidate_preferred_locations" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_candidate_preferred_locations`")  # noqa: E501
        # verify the required parameter 'x_ph_user_id' is set
        if ('x_ph_user_id' not in params or
                params['x_ph_user_id'] is None):
            raise ValueError("Missing the required parameter `x_ph_user_id` when calling `update_candidate_preferred_locations`")  # noqa: E501
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `update_candidate_preferred_locations`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_user_id' in params:
            header_params['x-ph-userId'] = params['x_ph_user_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/preferred-locations', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PreferredLocationUpdateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_candidate_profile(self, body, x_ph_user_id, candidate_id, **kwargs):  # noqa: E501
        """Update Candidate  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_candidate_profile(body, x_ph_user_id, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateCandidateRequest body: Update candidate profile. (required)
        :param str x_ph_user_id: (required)
        :param str candidate_id: Id of the candidate (required)
        :return: CandidateDetailsUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_candidate_profile_with_http_info(body, x_ph_user_id, candidate_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_candidate_profile_with_http_info(body, x_ph_user_id, candidate_id, **kwargs)  # noqa: E501
            return data

    def update_candidate_profile_with_http_info(self, body, x_ph_user_id, candidate_id, **kwargs):  # noqa: E501
        """Update Candidate  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_candidate_profile_with_http_info(body, x_ph_user_id, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateCandidateRequest body: Update candidate profile. (required)
        :param str x_ph_user_id: (required)
        :param str candidate_id: Id of the candidate (required)
        :return: CandidateDetailsUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_ph_user_id', 'candidate_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_candidate_profile" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_candidate_profile`")  # noqa: E501
        # verify the required parameter 'x_ph_user_id' is set
        if ('x_ph_user_id' not in params or
                params['x_ph_user_id'] is None):
            raise ValueError("Missing the required parameter `x_ph_user_id` when calling `update_candidate_profile`")  # noqa: E501
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `update_candidate_profile`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_user_id' in params:
            header_params['x-ph-userId'] = params['x_ph_user_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CandidateDetailsUpdateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_candidate_recommendations(self, body, x_ph_user_id, candidate_id, **kwargs):  # noqa: E501
        """Update Recommendations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_candidate_recommendations(body, x_ph_user_id, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateRecommendationsRequest body: Update recommendations of candidate (required)
        :param str x_ph_user_id: (required)
        :param str candidate_id: Id of the candidate (required)
        :return: RecommendationsUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_candidate_recommendations_with_http_info(body, x_ph_user_id, candidate_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_candidate_recommendations_with_http_info(body, x_ph_user_id, candidate_id, **kwargs)  # noqa: E501
            return data

    def update_candidate_recommendations_with_http_info(self, body, x_ph_user_id, candidate_id, **kwargs):  # noqa: E501
        """Update Recommendations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_candidate_recommendations_with_http_info(body, x_ph_user_id, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateRecommendationsRequest body: Update recommendations of candidate (required)
        :param str x_ph_user_id: (required)
        :param str candidate_id: Id of the candidate (required)
        :return: RecommendationsUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_ph_user_id', 'candidate_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_candidate_recommendations" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_candidate_recommendations`")  # noqa: E501
        # verify the required parameter 'x_ph_user_id' is set
        if ('x_ph_user_id' not in params or
                params['x_ph_user_id'] is None):
            raise ValueError("Missing the required parameter `x_ph_user_id` when calling `update_candidate_recommendations`")  # noqa: E501
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `update_candidate_recommendations`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_user_id' in params:
            header_params['x-ph-userId'] = params['x_ph_user_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/recommendations', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RecommendationsUpdateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_candidate_skills(self, body, x_ph_userid, candidate_id, **kwargs):  # noqa: E501
        """Update Skills  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_candidate_skills(body, x_ph_userid, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddSkillsRequest body: Add/update skills of a candidate (required)
        :param str x_ph_userid: (required)
        :param str candidate_id: Id of the candidate (required)
        :return: CandidateDetailsUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_candidate_skills_with_http_info(body, x_ph_userid, candidate_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_candidate_skills_with_http_info(body, x_ph_userid, candidate_id, **kwargs)  # noqa: E501
            return data

    def update_candidate_skills_with_http_info(self, body, x_ph_userid, candidate_id, **kwargs):  # noqa: E501
        """Update Skills  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_candidate_skills_with_http_info(body, x_ph_userid, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddSkillsRequest body: Add/update skills of a candidate (required)
        :param str x_ph_userid: (required)
        :param str candidate_id: Id of the candidate (required)
        :return: CandidateDetailsUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_ph_userid', 'candidate_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_candidate_skills" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_candidate_skills`")  # noqa: E501
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `update_candidate_skills`")  # noqa: E501
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `update_candidate_skills`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/skills', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CandidateDetailsUpdateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_tenant_specific_additional_fields(self, body, x_ph_userid, candidate_id, **kwargs):  # noqa: E501
        """Update Additional Fields  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_tenant_specific_additional_fields(body, x_ph_userid, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateAdditionalFieldsRequest body: Update tenant specific additional fields of a candidate (required)
        :param str x_ph_userid: (required)
        :param str candidate_id: Id of the candidate (required)
        :return: AdditionalFieldsUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_tenant_specific_additional_fields_with_http_info(body, x_ph_userid, candidate_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_tenant_specific_additional_fields_with_http_info(body, x_ph_userid, candidate_id, **kwargs)  # noqa: E501
            return data

    def update_tenant_specific_additional_fields_with_http_info(self, body, x_ph_userid, candidate_id, **kwargs):  # noqa: E501
        """Update Additional Fields  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_tenant_specific_additional_fields_with_http_info(body, x_ph_userid, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateAdditionalFieldsRequest body: Update tenant specific additional fields of a candidate (required)
        :param str x_ph_userid: (required)
        :param str candidate_id: Id of the candidate (required)
        :return: AdditionalFieldsUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_ph_userid', 'candidate_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_tenant_specific_additional_fields" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_tenant_specific_additional_fields`")  # noqa: E501
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `update_tenant_specific_additional_fields`")  # noqa: E501
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `update_tenant_specific_additional_fields`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/additional-fields', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AdditionalFieldsUpdateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    candidates-api-activities

    The Note APIs allows you to Add, Get, Update and Delete Notes.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class ProfileActionActivitiesData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'recruiters_user_id': 'str',
        'recruiter_name': 'str',
        'candidate_id': 'str',
        'action_type': 'str',
        'created_date': 'float',
        'request_source': 'str',
        'additional_field_name': 'str',
        'previous_value': 'str',
        'updated_value': 'str',
        'action_value': 'str',
        'source': 'str',
        'reason': 'str',
        'from_name': 'str',
        'to_name': 'str',
        'category_name': 'str',
        'email': 'str',
        'event': 'str'
    }

    attribute_map = {
        'recruiters_user_id': 'recruitersUserId',
        'recruiter_name': 'recruiterName',
        'candidate_id': 'candidateId',
        'action_type': 'actionType',
        'created_date': 'createdDate',
        'request_source': 'requestSource',
        'additional_field_name': 'additionalFieldName',
        'previous_value': 'previousValue',
        'updated_value': 'updatedValue',
        'action_value': 'actionValue',
        'source': 'source',
        'reason': 'reason',
        'from_name': 'fromName',
        'to_name': 'toName',
        'category_name': 'categoryName',
        'email': 'email',
        'event': 'event'
    }

    def __init__(self, recruiters_user_id=None, recruiter_name=None, candidate_id=None, action_type=None, created_date=None, request_source=None, additional_field_name=None, previous_value=None, updated_value=None, action_value=None, source=None, reason=None, from_name=None, to_name=None, category_name=None, email=None, event=None):  # noqa: E501
        """ProfileActionActivitiesData - a model defined in Swagger"""  # noqa: E501
        self._recruiters_user_id = None
        self._recruiter_name = None
        self._candidate_id = None
        self._action_type = None
        self._created_date = None
        self._request_source = None
        self._additional_field_name = None
        self._previous_value = None
        self._updated_value = None
        self._action_value = None
        self._source = None
        self._reason = None
        self._from_name = None
        self._to_name = None
        self._category_name = None
        self._email = None
        self._event = None
        self.discriminator = None
        if recruiters_user_id is not None:
            self.recruiters_user_id = recruiters_user_id
        if recruiter_name is not None:
            self.recruiter_name = recruiter_name
        if candidate_id is not None:
            self.candidate_id = candidate_id
        if action_type is not None:
            self.action_type = action_type
        if created_date is not None:
            self.created_date = created_date
        if request_source is not None:
            self.request_source = request_source
        if additional_field_name is not None:
            self.additional_field_name = additional_field_name
        if previous_value is not None:
            self.previous_value = previous_value
        if updated_value is not None:
            self.updated_value = updated_value
        if action_value is not None:
            self.action_value = action_value
        if source is not None:
            self.source = source
        if reason is not None:
            self.reason = reason
        if from_name is not None:
            self.from_name = from_name
        if to_name is not None:
            self.to_name = to_name
        if category_name is not None:
            self.category_name = category_name
        if email is not None:
            self.email = email
        if event is not None:
            self.event = event

    @property
    def recruiters_user_id(self):
        """Gets the recruiters_user_id of this ProfileActionActivitiesData.  # noqa: E501

        The user ID of the recruiter associated with the profile action activity.  # noqa: E501

        :return: The recruiters_user_id of this ProfileActionActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._recruiters_user_id

    @recruiters_user_id.setter
    def recruiters_user_id(self, recruiters_user_id):
        """Sets the recruiters_user_id of this ProfileActionActivitiesData.

        The user ID of the recruiter associated with the profile action activity.  # noqa: E501

        :param recruiters_user_id: The recruiters_user_id of this ProfileActionActivitiesData.  # noqa: E501
        :type: str
        """

        self._recruiters_user_id = recruiters_user_id

    @property
    def recruiter_name(self):
        """Gets the recruiter_name of this ProfileActionActivitiesData.  # noqa: E501

        The name of the recruiter associated with the profile action activity.  # noqa: E501

        :return: The recruiter_name of this ProfileActionActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_name

    @recruiter_name.setter
    def recruiter_name(self, recruiter_name):
        """Sets the recruiter_name of this ProfileActionActivitiesData.

        The name of the recruiter associated with the profile action activity.  # noqa: E501

        :param recruiter_name: The recruiter_name of this ProfileActionActivitiesData.  # noqa: E501
        :type: str
        """

        self._recruiter_name = recruiter_name

    @property
    def candidate_id(self):
        """Gets the candidate_id of this ProfileActionActivitiesData.  # noqa: E501

        The ID of the candidate associated with the profile action activity.  # noqa: E501

        :return: The candidate_id of this ProfileActionActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._candidate_id

    @candidate_id.setter
    def candidate_id(self, candidate_id):
        """Sets the candidate_id of this ProfileActionActivitiesData.

        The ID of the candidate associated with the profile action activity.  # noqa: E501

        :param candidate_id: The candidate_id of this ProfileActionActivitiesData.  # noqa: E501
        :type: str
        """

        self._candidate_id = candidate_id

    @property
    def action_type(self):
        """Gets the action_type of this ProfileActionActivitiesData.  # noqa: E501

        The type of action performed in the profile action activity.  # noqa: E501

        :return: The action_type of this ProfileActionActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._action_type

    @action_type.setter
    def action_type(self, action_type):
        """Sets the action_type of this ProfileActionActivitiesData.

        The type of action performed in the profile action activity.  # noqa: E501

        :param action_type: The action_type of this ProfileActionActivitiesData.  # noqa: E501
        :type: str
        """

        self._action_type = action_type

    @property
    def created_date(self):
        """Gets the created_date of this ProfileActionActivitiesData.  # noqa: E501

        The date when the profile action activity was created.  # noqa: E501

        :return: The created_date of this ProfileActionActivitiesData.  # noqa: E501
        :rtype: float
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this ProfileActionActivitiesData.

        The date when the profile action activity was created.  # noqa: E501

        :param created_date: The created_date of this ProfileActionActivitiesData.  # noqa: E501
        :type: float
        """

        self._created_date = created_date

    @property
    def request_source(self):
        """Gets the request_source of this ProfileActionActivitiesData.  # noqa: E501

        The source from which the profile action activity request originated.  # noqa: E501

        :return: The request_source of this ProfileActionActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._request_source

    @request_source.setter
    def request_source(self, request_source):
        """Sets the request_source of this ProfileActionActivitiesData.

        The source from which the profile action activity request originated.  # noqa: E501

        :param request_source: The request_source of this ProfileActionActivitiesData.  # noqa: E501
        :type: str
        """

        self._request_source = request_source

    @property
    def additional_field_name(self):
        """Gets the additional_field_name of this ProfileActionActivitiesData.  # noqa: E501

        The name of the additional field associated with the profile action activity.  # noqa: E501

        :return: The additional_field_name of this ProfileActionActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._additional_field_name

    @additional_field_name.setter
    def additional_field_name(self, additional_field_name):
        """Sets the additional_field_name of this ProfileActionActivitiesData.

        The name of the additional field associated with the profile action activity.  # noqa: E501

        :param additional_field_name: The additional_field_name of this ProfileActionActivitiesData.  # noqa: E501
        :type: str
        """

        self._additional_field_name = additional_field_name

    @property
    def previous_value(self):
        """Gets the previous_value of this ProfileActionActivitiesData.  # noqa: E501

        The previous value of the updated field.  # noqa: E501

        :return: The previous_value of this ProfileActionActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._previous_value

    @previous_value.setter
    def previous_value(self, previous_value):
        """Sets the previous_value of this ProfileActionActivitiesData.

        The previous value of the updated field.  # noqa: E501

        :param previous_value: The previous_value of this ProfileActionActivitiesData.  # noqa: E501
        :type: str
        """

        self._previous_value = previous_value

    @property
    def updated_value(self):
        """Gets the updated_value of this ProfileActionActivitiesData.  # noqa: E501

        The updated value of the field in the profile action activity.  # noqa: E501

        :return: The updated_value of this ProfileActionActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._updated_value

    @updated_value.setter
    def updated_value(self, updated_value):
        """Sets the updated_value of this ProfileActionActivitiesData.

        The updated value of the field in the profile action activity.  # noqa: E501

        :param updated_value: The updated_value of this ProfileActionActivitiesData.  # noqa: E501
        :type: str
        """

        self._updated_value = updated_value

    @property
    def action_value(self):
        """Gets the action_value of this ProfileActionActivitiesData.  # noqa: E501

        The value associated with the action performed in the profile action activity.  # noqa: E501

        :return: The action_value of this ProfileActionActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._action_value

    @action_value.setter
    def action_value(self, action_value):
        """Sets the action_value of this ProfileActionActivitiesData.

        The value associated with the action performed in the profile action activity.  # noqa: E501

        :param action_value: The action_value of this ProfileActionActivitiesData.  # noqa: E501
        :type: str
        """

        self._action_value = action_value

    @property
    def source(self):
        """Gets the source of this ProfileActionActivitiesData.  # noqa: E501

        The source or origin of the profile action activity.  # noqa: E501

        :return: The source of this ProfileActionActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this ProfileActionActivitiesData.

        The source or origin of the profile action activity.  # noqa: E501

        :param source: The source of this ProfileActionActivitiesData.  # noqa: E501
        :type: str
        """

        self._source = source

    @property
    def reason(self):
        """Gets the reason of this ProfileActionActivitiesData.  # noqa: E501

        The reason or justification for the profile action activity.  # noqa: E501

        :return: The reason of this ProfileActionActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this ProfileActionActivitiesData.

        The reason or justification for the profile action activity.  # noqa: E501

        :param reason: The reason of this ProfileActionActivitiesData.  # noqa: E501
        :type: str
        """

        self._reason = reason

    @property
    def from_name(self):
        """Gets the from_name of this ProfileActionActivitiesData.  # noqa: E501

        The name associated with the sender of the profile action activity.  # noqa: E501

        :return: The from_name of this ProfileActionActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._from_name

    @from_name.setter
    def from_name(self, from_name):
        """Sets the from_name of this ProfileActionActivitiesData.

        The name associated with the sender of the profile action activity.  # noqa: E501

        :param from_name: The from_name of this ProfileActionActivitiesData.  # noqa: E501
        :type: str
        """

        self._from_name = from_name

    @property
    def to_name(self):
        """Gets the to_name of this ProfileActionActivitiesData.  # noqa: E501

        The name of the recipient in the profile action activity.  # noqa: E501

        :return: The to_name of this ProfileActionActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._to_name

    @to_name.setter
    def to_name(self, to_name):
        """Sets the to_name of this ProfileActionActivitiesData.

        The name of the recipient in the profile action activity.  # noqa: E501

        :param to_name: The to_name of this ProfileActionActivitiesData.  # noqa: E501
        :type: str
        """

        self._to_name = to_name

    @property
    def category_name(self):
        """Gets the category_name of this ProfileActionActivitiesData.  # noqa: E501

        The name of the category associated with the profile action activity.  # noqa: E501

        :return: The category_name of this ProfileActionActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._category_name

    @category_name.setter
    def category_name(self, category_name):
        """Sets the category_name of this ProfileActionActivitiesData.

        The name of the category associated with the profile action activity.  # noqa: E501

        :param category_name: The category_name of this ProfileActionActivitiesData.  # noqa: E501
        :type: str
        """

        self._category_name = category_name

    @property
    def email(self):
        """Gets the email of this ProfileActionActivitiesData.  # noqa: E501

        The email associated with the profile action activity.  # noqa: E501

        :return: The email of this ProfileActionActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this ProfileActionActivitiesData.

        The email associated with the profile action activity.  # noqa: E501

        :param email: The email of this ProfileActionActivitiesData.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def event(self):
        """Gets the event of this ProfileActionActivitiesData.  # noqa: E501

        The event or occurrence associated with the profile action activity.  # noqa: E501

        :return: The event of this ProfileActionActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._event

    @event.setter
    def event(self, event):
        """Sets the event of this ProfileActionActivitiesData.

        The event or occurrence associated with the profile action activity.  # noqa: E501

        :param event: The event of this ProfileActionActivitiesData.  # noqa: E501
        :type: str
        """

        self._event = event

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProfileActionActivitiesData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProfileActionActivitiesData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from phenom.api.projects.candidates_api import CandidatesApi
from phenom.api.projects.workflows_api import WorkflowsApi
from phenom.api.projects.projects_api import ProjectsApi
from phenom.api.projects.workflow_status_api import WorkflowStatusApi

class Projects(object):
    def __init__(self, token, gateway_url, apikey):
        self.__token = token
        self.__gateway_url = gateway_url
        self.__apikey = apikey
    def candidates_api(self):
        return CandidatesApi(self.__token, self.__gateway_url, self.__apikey)
    def workflows_api(self):
        return WorkflowsApi(self.__token, self.__gateway_url, self.__apikey)
    def projects_api(self):
        return ProjectsApi(self.__token, self.__gateway_url, self.__apikey)
    def workflow_status_api(self):
        return WorkflowStatusApi(self.__token, self.__gateway_url, self.__apikey)



# coding: utf-8

"""
    applicants-api

    This API collection enables seamless operations by facilitating the retrieval of essential applicant details, updating and managing hiring statuses for candidates, assigning multiple candidates as leads for specific job roles, and obtaining detailed activity logs associated with applicants.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class HiringStatusActivitiesData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'recruiters_user_id': 'str',
        'recruiter_name': 'str',
        'candidate_id': 'str',
        'action_type': 'str',
        'created_date': 'float',
        'request_source': 'str',
        'additional_field_name': 'str',
        'previous_value': 'str',
        'updated_value': 'str',
        'action_value': 'str',
        'subject': 'str',
        'content': 'str',
        'category_name': 'str',
        'email_response': 'str',
        'from_email': 'str',
        'from_name': 'str',
        'to_email': 'str',
        'to_name': 'str',
        'recipe_name': 'str',
        'added_new_value': 'str'
    }

    attribute_map = {
        'recruiters_user_id': 'recruitersUserId',
        'recruiter_name': 'recruiterName',
        'candidate_id': 'candidateId',
        'action_type': 'actionType',
        'created_date': 'createdDate',
        'request_source': 'requestSource',
        'additional_field_name': 'additionalFieldName',
        'previous_value': 'previousValue',
        'updated_value': 'updatedValue',
        'action_value': 'actionValue',
        'subject': 'subject',
        'content': 'content',
        'category_name': 'categoryName',
        'email_response': 'emailResponse',
        'from_email': 'fromEmail',
        'from_name': 'fromName',
        'to_email': 'toEmail',
        'to_name': 'toName',
        'recipe_name': 'recipeName',
        'added_new_value': 'addedNewValue'
    }

    def __init__(self, recruiters_user_id=None, recruiter_name=None, candidate_id=None, action_type=None, created_date=None, request_source=None, additional_field_name=None, previous_value=None, updated_value=None, action_value=None, subject=None, content=None, category_name=None, email_response=None, from_email=None, from_name=None, to_email=None, to_name=None, recipe_name=None, added_new_value=None):  # noqa: E501
        """HiringStatusActivitiesData - a model defined in Swagger"""  # noqa: E501
        self._recruiters_user_id = None
        self._recruiter_name = None
        self._candidate_id = None
        self._action_type = None
        self._created_date = None
        self._request_source = None
        self._additional_field_name = None
        self._previous_value = None
        self._updated_value = None
        self._action_value = None
        self._subject = None
        self._content = None
        self._category_name = None
        self._email_response = None
        self._from_email = None
        self._from_name = None
        self._to_email = None
        self._to_name = None
        self._recipe_name = None
        self._added_new_value = None
        self.discriminator = None
        if recruiters_user_id is not None:
            self.recruiters_user_id = recruiters_user_id
        if recruiter_name is not None:
            self.recruiter_name = recruiter_name
        if candidate_id is not None:
            self.candidate_id = candidate_id
        if action_type is not None:
            self.action_type = action_type
        if created_date is not None:
            self.created_date = created_date
        if request_source is not None:
            self.request_source = request_source
        if additional_field_name is not None:
            self.additional_field_name = additional_field_name
        if previous_value is not None:
            self.previous_value = previous_value
        if updated_value is not None:
            self.updated_value = updated_value
        if action_value is not None:
            self.action_value = action_value
        if subject is not None:
            self.subject = subject
        if content is not None:
            self.content = content
        if category_name is not None:
            self.category_name = category_name
        if email_response is not None:
            self.email_response = email_response
        if from_email is not None:
            self.from_email = from_email
        if from_name is not None:
            self.from_name = from_name
        if to_email is not None:
            self.to_email = to_email
        if to_name is not None:
            self.to_name = to_name
        if recipe_name is not None:
            self.recipe_name = recipe_name
        if added_new_value is not None:
            self.added_new_value = added_new_value

    @property
    def recruiters_user_id(self):
        """Gets the recruiters_user_id of this HiringStatusActivitiesData.  # noqa: E501

        User ID of the recruiter associated with the activity.  # noqa: E501

        :return: The recruiters_user_id of this HiringStatusActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._recruiters_user_id

    @recruiters_user_id.setter
    def recruiters_user_id(self, recruiters_user_id):
        """Sets the recruiters_user_id of this HiringStatusActivitiesData.

        User ID of the recruiter associated with the activity.  # noqa: E501

        :param recruiters_user_id: The recruiters_user_id of this HiringStatusActivitiesData.  # noqa: E501
        :type: str
        """

        self._recruiters_user_id = recruiters_user_id

    @property
    def recruiter_name(self):
        """Gets the recruiter_name of this HiringStatusActivitiesData.  # noqa: E501

        Name of the recruiter associated with the activity.  # noqa: E501

        :return: The recruiter_name of this HiringStatusActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_name

    @recruiter_name.setter
    def recruiter_name(self, recruiter_name):
        """Sets the recruiter_name of this HiringStatusActivitiesData.

        Name of the recruiter associated with the activity.  # noqa: E501

        :param recruiter_name: The recruiter_name of this HiringStatusActivitiesData.  # noqa: E501
        :type: str
        """

        self._recruiter_name = recruiter_name

    @property
    def candidate_id(self):
        """Gets the candidate_id of this HiringStatusActivitiesData.  # noqa: E501

        ID of the candidate associated with the activity.  # noqa: E501

        :return: The candidate_id of this HiringStatusActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._candidate_id

    @candidate_id.setter
    def candidate_id(self, candidate_id):
        """Sets the candidate_id of this HiringStatusActivitiesData.

        ID of the candidate associated with the activity.  # noqa: E501

        :param candidate_id: The candidate_id of this HiringStatusActivitiesData.  # noqa: E501
        :type: str
        """

        self._candidate_id = candidate_id

    @property
    def action_type(self):
        """Gets the action_type of this HiringStatusActivitiesData.  # noqa: E501

        Type of action performed in the activity.  # noqa: E501

        :return: The action_type of this HiringStatusActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._action_type

    @action_type.setter
    def action_type(self, action_type):
        """Sets the action_type of this HiringStatusActivitiesData.

        Type of action performed in the activity.  # noqa: E501

        :param action_type: The action_type of this HiringStatusActivitiesData.  # noqa: E501
        :type: str
        """

        self._action_type = action_type

    @property
    def created_date(self):
        """Gets the created_date of this HiringStatusActivitiesData.  # noqa: E501

        Date when the activity was created.  # noqa: E501

        :return: The created_date of this HiringStatusActivitiesData.  # noqa: E501
        :rtype: float
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this HiringStatusActivitiesData.

        Date when the activity was created.  # noqa: E501

        :param created_date: The created_date of this HiringStatusActivitiesData.  # noqa: E501
        :type: float
        """

        self._created_date = created_date

    @property
    def request_source(self):
        """Gets the request_source of this HiringStatusActivitiesData.  # noqa: E501

        Source of the activity request.  # noqa: E501

        :return: The request_source of this HiringStatusActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._request_source

    @request_source.setter
    def request_source(self, request_source):
        """Sets the request_source of this HiringStatusActivitiesData.

        Source of the activity request.  # noqa: E501

        :param request_source: The request_source of this HiringStatusActivitiesData.  # noqa: E501
        :type: str
        """

        self._request_source = request_source

    @property
    def additional_field_name(self):
        """Gets the additional_field_name of this HiringStatusActivitiesData.  # noqa: E501

        Name of the additional field associated with the activity.  # noqa: E501

        :return: The additional_field_name of this HiringStatusActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._additional_field_name

    @additional_field_name.setter
    def additional_field_name(self, additional_field_name):
        """Sets the additional_field_name of this HiringStatusActivitiesData.

        Name of the additional field associated with the activity.  # noqa: E501

        :param additional_field_name: The additional_field_name of this HiringStatusActivitiesData.  # noqa: E501
        :type: str
        """

        self._additional_field_name = additional_field_name

    @property
    def previous_value(self):
        """Gets the previous_value of this HiringStatusActivitiesData.  # noqa: E501

        Previous value of the additional field.  # noqa: E501

        :return: The previous_value of this HiringStatusActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._previous_value

    @previous_value.setter
    def previous_value(self, previous_value):
        """Sets the previous_value of this HiringStatusActivitiesData.

        Previous value of the additional field.  # noqa: E501

        :param previous_value: The previous_value of this HiringStatusActivitiesData.  # noqa: E501
        :type: str
        """

        self._previous_value = previous_value

    @property
    def updated_value(self):
        """Gets the updated_value of this HiringStatusActivitiesData.  # noqa: E501

        Updated value of the additional field.  # noqa: E501

        :return: The updated_value of this HiringStatusActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._updated_value

    @updated_value.setter
    def updated_value(self, updated_value):
        """Sets the updated_value of this HiringStatusActivitiesData.

        Updated value of the additional field.  # noqa: E501

        :param updated_value: The updated_value of this HiringStatusActivitiesData.  # noqa: E501
        :type: str
        """

        self._updated_value = updated_value

    @property
    def action_value(self):
        """Gets the action_value of this HiringStatusActivitiesData.  # noqa: E501

        Value associated with the action.  # noqa: E501

        :return: The action_value of this HiringStatusActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._action_value

    @action_value.setter
    def action_value(self, action_value):
        """Sets the action_value of this HiringStatusActivitiesData.

        Value associated with the action.  # noqa: E501

        :param action_value: The action_value of this HiringStatusActivitiesData.  # noqa: E501
        :type: str
        """

        self._action_value = action_value

    @property
    def subject(self):
        """Gets the subject of this HiringStatusActivitiesData.  # noqa: E501

        Subject of the activity.  # noqa: E501

        :return: The subject of this HiringStatusActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this HiringStatusActivitiesData.

        Subject of the activity.  # noqa: E501

        :param subject: The subject of this HiringStatusActivitiesData.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def content(self):
        """Gets the content of this HiringStatusActivitiesData.  # noqa: E501

        Content of the activity.  # noqa: E501

        :return: The content of this HiringStatusActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this HiringStatusActivitiesData.

        Content of the activity.  # noqa: E501

        :param content: The content of this HiringStatusActivitiesData.  # noqa: E501
        :type: str
        """

        self._content = content

    @property
    def category_name(self):
        """Gets the category_name of this HiringStatusActivitiesData.  # noqa: E501

        Name of the category associated with the activity.  # noqa: E501

        :return: The category_name of this HiringStatusActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._category_name

    @category_name.setter
    def category_name(self, category_name):
        """Sets the category_name of this HiringStatusActivitiesData.

        Name of the category associated with the activity.  # noqa: E501

        :param category_name: The category_name of this HiringStatusActivitiesData.  # noqa: E501
        :type: str
        """

        self._category_name = category_name

    @property
    def email_response(self):
        """Gets the email_response of this HiringStatusActivitiesData.  # noqa: E501

        Email response associated with the activity.  # noqa: E501

        :return: The email_response of this HiringStatusActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._email_response

    @email_response.setter
    def email_response(self, email_response):
        """Sets the email_response of this HiringStatusActivitiesData.

        Email response associated with the activity.  # noqa: E501

        :param email_response: The email_response of this HiringStatusActivitiesData.  # noqa: E501
        :type: str
        """

        self._email_response = email_response

    @property
    def from_email(self):
        """Gets the from_email of this HiringStatusActivitiesData.  # noqa: E501

        Email address from which the activity originated.  # noqa: E501

        :return: The from_email of this HiringStatusActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._from_email

    @from_email.setter
    def from_email(self, from_email):
        """Sets the from_email of this HiringStatusActivitiesData.

        Email address from which the activity originated.  # noqa: E501

        :param from_email: The from_email of this HiringStatusActivitiesData.  # noqa: E501
        :type: str
        """

        self._from_email = from_email

    @property
    def from_name(self):
        """Gets the from_name of this HiringStatusActivitiesData.  # noqa: E501

        Name associated with the sender of the activity.  # noqa: E501

        :return: The from_name of this HiringStatusActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._from_name

    @from_name.setter
    def from_name(self, from_name):
        """Sets the from_name of this HiringStatusActivitiesData.

        Name associated with the sender of the activity.  # noqa: E501

        :param from_name: The from_name of this HiringStatusActivitiesData.  # noqa: E501
        :type: str
        """

        self._from_name = from_name

    @property
    def to_email(self):
        """Gets the to_email of this HiringStatusActivitiesData.  # noqa: E501

        Email address of the recipient of the activity.  # noqa: E501

        :return: The to_email of this HiringStatusActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._to_email

    @to_email.setter
    def to_email(self, to_email):
        """Sets the to_email of this HiringStatusActivitiesData.

        Email address of the recipient of the activity.  # noqa: E501

        :param to_email: The to_email of this HiringStatusActivitiesData.  # noqa: E501
        :type: str
        """

        self._to_email = to_email

    @property
    def to_name(self):
        """Gets the to_name of this HiringStatusActivitiesData.  # noqa: E501

        Name of the recipient of the activity.  # noqa: E501

        :return: The to_name of this HiringStatusActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._to_name

    @to_name.setter
    def to_name(self, to_name):
        """Sets the to_name of this HiringStatusActivitiesData.

        Name of the recipient of the activity.  # noqa: E501

        :param to_name: The to_name of this HiringStatusActivitiesData.  # noqa: E501
        :type: str
        """

        self._to_name = to_name

    @property
    def recipe_name(self):
        """Gets the recipe_name of this HiringStatusActivitiesData.  # noqa: E501

        Name of the recipe associated with the activity.  # noqa: E501

        :return: The recipe_name of this HiringStatusActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._recipe_name

    @recipe_name.setter
    def recipe_name(self, recipe_name):
        """Sets the recipe_name of this HiringStatusActivitiesData.

        Name of the recipe associated with the activity.  # noqa: E501

        :param recipe_name: The recipe_name of this HiringStatusActivitiesData.  # noqa: E501
        :type: str
        """

        self._recipe_name = recipe_name

    @property
    def added_new_value(self):
        """Gets the added_new_value of this HiringStatusActivitiesData.  # noqa: E501

        New value added in the activity.  # noqa: E501

        :return: The added_new_value of this HiringStatusActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._added_new_value

    @added_new_value.setter
    def added_new_value(self, added_new_value):
        """Sets the added_new_value of this HiringStatusActivitiesData.

        New value added in the activity.  # noqa: E501

        :param added_new_value: The added_new_value of this HiringStatusActivitiesData.  # noqa: E501
        :type: str
        """

        self._added_new_value = added_new_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HiringStatusActivitiesData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HiringStatusActivitiesData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    servicehub-public-api

    Public APIs for managing user data.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class SearchRequestDateFilter(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'start_date': 'str',
        'end_date': 'str'
    }

    attribute_map = {
        'name': 'name',
        'start_date': 'startDate',
        'end_date': 'endDate'
    }

    def __init__(self, name=None, start_date=None, end_date=None):  # noqa: E501
        """SearchRequestDateFilter - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._start_date = None
        self._end_date = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if start_date is not None:
            self.start_date = start_date
        if end_date is not None:
            self.end_date = end_date

    @property
    def name(self):
        """Gets the name of this SearchRequestDateFilter.  # noqa: E501

        Name of the date filter.  # noqa: E501

        :return: The name of this SearchRequestDateFilter.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SearchRequestDateFilter.

        Name of the date filter.  # noqa: E501

        :param name: The name of this SearchRequestDateFilter.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def start_date(self):
        """Gets the start_date of this SearchRequestDateFilter.  # noqa: E501

        Start date for the date filter.  # noqa: E501

        :return: The start_date of this SearchRequestDateFilter.  # noqa: E501
        :rtype: str
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this SearchRequestDateFilter.

        Start date for the date filter.  # noqa: E501

        :param start_date: The start_date of this SearchRequestDateFilter.  # noqa: E501
        :type: str
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this SearchRequestDateFilter.  # noqa: E501

        End date for the date filter.  # noqa: E501

        :return: The end_date of this SearchRequestDateFilter.  # noqa: E501
        :rtype: str
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this SearchRequestDateFilter.

        End date for the date filter.  # noqa: E501

        :param end_date: The end_date of this SearchRequestDateFilter.  # noqa: E501
        :type: str
        """

        self._end_date = end_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SearchRequestDateFilter, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchRequestDateFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetInterviewDetailsResponseDataCandidateInfo(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'first_name': 'str',
        'last_name': 'str',
        'email': 'str',
        'candidate_id': 'str',
        'preferred_first_name': 'str'
    }

    attribute_map = {
        'first_name': 'firstName',
        'last_name': 'lastName',
        'email': 'email',
        'candidate_id': 'candidateId',
        'preferred_first_name': 'preferredFirstName'
    }

    def __init__(self, first_name=None, last_name=None, email=None, candidate_id=None, preferred_first_name=None):  # noqa: E501
        """GetInterviewDetailsResponseDataCandidateInfo - a model defined in Swagger"""  # noqa: E501
        self._first_name = None
        self._last_name = None
        self._email = None
        self._candidate_id = None
        self._preferred_first_name = None
        self.discriminator = None
        self.first_name = first_name
        self.last_name = last_name
        self.email = email
        self.candidate_id = candidate_id
        self.preferred_first_name = preferred_first_name

    @property
    def first_name(self):
        """Gets the first_name of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501

        Candidate first name.  # noqa: E501

        :return: The first_name of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this GetInterviewDetailsResponseDataCandidateInfo.

        Candidate first name.  # noqa: E501

        :param first_name: The first_name of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501
        :type: str
        """
        if first_name is None:
            raise ValueError("Invalid value for `first_name`, must not be `None`")  # noqa: E501

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501

        Candidate last name.  # noqa: E501

        :return: The last_name of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this GetInterviewDetailsResponseDataCandidateInfo.

        Candidate last name.  # noqa: E501

        :param last_name: The last_name of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501
        :type: str
        """
        if last_name is None:
            raise ValueError("Invalid value for `last_name`, must not be `None`")  # noqa: E501

        self._last_name = last_name

    @property
    def email(self):
        """Gets the email of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501

        Candidate email.  # noqa: E501

        :return: The email of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this GetInterviewDetailsResponseDataCandidateInfo.

        Candidate email.  # noqa: E501

        :param email: The email of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501
        :type: str
        """
        if email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def candidate_id(self):
        """Gets the candidate_id of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501

        Candidate id.  # noqa: E501

        :return: The candidate_id of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501
        :rtype: str
        """
        return self._candidate_id

    @candidate_id.setter
    def candidate_id(self, candidate_id):
        """Sets the candidate_id of this GetInterviewDetailsResponseDataCandidateInfo.

        Candidate id.  # noqa: E501

        :param candidate_id: The candidate_id of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501
        :type: str
        """
        if candidate_id is None:
            raise ValueError("Invalid value for `candidate_id`, must not be `None`")  # noqa: E501

        self._candidate_id = candidate_id

    @property
    def preferred_first_name(self):
        """Gets the preferred_first_name of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501

        Candidate preferred first name.  # noqa: E501

        :return: The preferred_first_name of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501
        :rtype: str
        """
        return self._preferred_first_name

    @preferred_first_name.setter
    def preferred_first_name(self, preferred_first_name):
        """Sets the preferred_first_name of this GetInterviewDetailsResponseDataCandidateInfo.

        Candidate preferred first name.  # noqa: E501

        :param preferred_first_name: The preferred_first_name of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501
        :type: str
        """
        if preferred_first_name is None:
            raise ValueError("Invalid value for `preferred_first_name`, must not be `None`")  # noqa: E501

        self._preferred_first_name = preferred_first_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetInterviewDetailsResponseDataCandidateInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetInterviewDetailsResponseDataCandidateInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    jobs-questionnarie-api

    These APIs streamline question management, providing tools to create, delete, and update questions. Additionally, they offer functionality to attach question lists to specific job profiles.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetQuestionnarieTemplatesResponseData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'questionnaire_name': 'str',
        'job_category': 'str',
        'recruiter_name': 'str',
        'recruiter_user_id': 'str',
        'as_default': 'str',
        'updated_date': 'float',
        'template_id': 'str'
    }

    attribute_map = {
        'questionnaire_name': 'questionnaireName',
        'job_category': 'jobCategory',
        'recruiter_name': 'recruiterName',
        'recruiter_user_id': 'recruiterUserId',
        'as_default': 'asDefault',
        'updated_date': 'updatedDate',
        'template_id': 'templateId'
    }

    def __init__(self, questionnaire_name=None, job_category=None, recruiter_name=None, recruiter_user_id=None, as_default=None, updated_date=None, template_id=None):  # noqa: E501
        """GetQuestionnarieTemplatesResponseData - a model defined in Swagger"""  # noqa: E501
        self._questionnaire_name = None
        self._job_category = None
        self._recruiter_name = None
        self._recruiter_user_id = None
        self._as_default = None
        self._updated_date = None
        self._template_id = None
        self.discriminator = None
        if questionnaire_name is not None:
            self.questionnaire_name = questionnaire_name
        if job_category is not None:
            self.job_category = job_category
        if recruiter_name is not None:
            self.recruiter_name = recruiter_name
        if recruiter_user_id is not None:
            self.recruiter_user_id = recruiter_user_id
        if as_default is not None:
            self.as_default = as_default
        if updated_date is not None:
            self.updated_date = updated_date
        if template_id is not None:
            self.template_id = template_id

    @property
    def questionnaire_name(self):
        """Gets the questionnaire_name of this GetQuestionnarieTemplatesResponseData.  # noqa: E501

        Name of the questionnaire.  # noqa: E501

        :return: The questionnaire_name of this GetQuestionnarieTemplatesResponseData.  # noqa: E501
        :rtype: str
        """
        return self._questionnaire_name

    @questionnaire_name.setter
    def questionnaire_name(self, questionnaire_name):
        """Sets the questionnaire_name of this GetQuestionnarieTemplatesResponseData.

        Name of the questionnaire.  # noqa: E501

        :param questionnaire_name: The questionnaire_name of this GetQuestionnarieTemplatesResponseData.  # noqa: E501
        :type: str
        """

        self._questionnaire_name = questionnaire_name

    @property
    def job_category(self):
        """Gets the job_category of this GetQuestionnarieTemplatesResponseData.  # noqa: E501

        Category associated with the job.  # noqa: E501

        :return: The job_category of this GetQuestionnarieTemplatesResponseData.  # noqa: E501
        :rtype: str
        """
        return self._job_category

    @job_category.setter
    def job_category(self, job_category):
        """Sets the job_category of this GetQuestionnarieTemplatesResponseData.

        Category associated with the job.  # noqa: E501

        :param job_category: The job_category of this GetQuestionnarieTemplatesResponseData.  # noqa: E501
        :type: str
        """

        self._job_category = job_category

    @property
    def recruiter_name(self):
        """Gets the recruiter_name of this GetQuestionnarieTemplatesResponseData.  # noqa: E501

        Name of the recruiter.  # noqa: E501

        :return: The recruiter_name of this GetQuestionnarieTemplatesResponseData.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_name

    @recruiter_name.setter
    def recruiter_name(self, recruiter_name):
        """Sets the recruiter_name of this GetQuestionnarieTemplatesResponseData.

        Name of the recruiter.  # noqa: E501

        :param recruiter_name: The recruiter_name of this GetQuestionnarieTemplatesResponseData.  # noqa: E501
        :type: str
        """

        self._recruiter_name = recruiter_name

    @property
    def recruiter_user_id(self):
        """Gets the recruiter_user_id of this GetQuestionnarieTemplatesResponseData.  # noqa: E501

        Unique identifier of the recruiter.  # noqa: E501

        :return: The recruiter_user_id of this GetQuestionnarieTemplatesResponseData.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_user_id

    @recruiter_user_id.setter
    def recruiter_user_id(self, recruiter_user_id):
        """Sets the recruiter_user_id of this GetQuestionnarieTemplatesResponseData.

        Unique identifier of the recruiter.  # noqa: E501

        :param recruiter_user_id: The recruiter_user_id of this GetQuestionnarieTemplatesResponseData.  # noqa: E501
        :type: str
        """

        self._recruiter_user_id = recruiter_user_id

    @property
    def as_default(self):
        """Gets the as_default of this GetQuestionnarieTemplatesResponseData.  # noqa: E501

        Indicator if the questionnaire is set as default.  # noqa: E501

        :return: The as_default of this GetQuestionnarieTemplatesResponseData.  # noqa: E501
        :rtype: str
        """
        return self._as_default

    @as_default.setter
    def as_default(self, as_default):
        """Sets the as_default of this GetQuestionnarieTemplatesResponseData.

        Indicator if the questionnaire is set as default.  # noqa: E501

        :param as_default: The as_default of this GetQuestionnarieTemplatesResponseData.  # noqa: E501
        :type: str
        """

        self._as_default = as_default

    @property
    def updated_date(self):
        """Gets the updated_date of this GetQuestionnarieTemplatesResponseData.  # noqa: E501

        Timestamp indicating the date of the last update.  # noqa: E501

        :return: The updated_date of this GetQuestionnarieTemplatesResponseData.  # noqa: E501
        :rtype: float
        """
        return self._updated_date

    @updated_date.setter
    def updated_date(self, updated_date):
        """Sets the updated_date of this GetQuestionnarieTemplatesResponseData.

        Timestamp indicating the date of the last update.  # noqa: E501

        :param updated_date: The updated_date of this GetQuestionnarieTemplatesResponseData.  # noqa: E501
        :type: float
        """

        self._updated_date = updated_date

    @property
    def template_id(self):
        """Gets the template_id of this GetQuestionnarieTemplatesResponseData.  # noqa: E501

        Unique identifier of the template.  # noqa: E501

        :return: The template_id of this GetQuestionnarieTemplatesResponseData.  # noqa: E501
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this GetQuestionnarieTemplatesResponseData.

        Unique identifier of the template.  # noqa: E501

        :param template_id: The template_id of this GetQuestionnarieTemplatesResponseData.  # noqa: E501
        :type: str
        """

        self._template_id = template_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetQuestionnarieTemplatesResponseData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetQuestionnarieTemplatesResponseData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class CreateWorkflowRequestFurtherTransitionStages(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'status_code': 'str'
    }

    attribute_map = {
        'name': 'name',
        'status_code': 'statusCode'
    }

    def __init__(self, name=None, status_code=None):  # noqa: E501
        """CreateWorkflowRequestFurtherTransitionStages - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._status_code = None
        self.discriminator = None
        self.name = name
        self.status_code = status_code

    @property
    def name(self):
        """Gets the name of this CreateWorkflowRequestFurtherTransitionStages.  # noqa: E501

        Name of the further transition stage.  # noqa: E501

        :return: The name of this CreateWorkflowRequestFurtherTransitionStages.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateWorkflowRequestFurtherTransitionStages.

        Name of the further transition stage.  # noqa: E501

        :param name: The name of this CreateWorkflowRequestFurtherTransitionStages.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def status_code(self):
        """Gets the status_code of this CreateWorkflowRequestFurtherTransitionStages.  # noqa: E501

        Status code associated with the further transition stage.  # noqa: E501

        :return: The status_code of this CreateWorkflowRequestFurtherTransitionStages.  # noqa: E501
        :rtype: str
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """Sets the status_code of this CreateWorkflowRequestFurtherTransitionStages.

        Status code associated with the further transition stage.  # noqa: E501

        :param status_code: The status_code of this CreateWorkflowRequestFurtherTransitionStages.  # noqa: E501
        :type: str
        """
        if status_code is None:
            raise ValueError("Invalid value for `status_code`, must not be `None`")  # noqa: E501

        self._status_code = status_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateWorkflowRequestFurtherTransitionStages, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateWorkflowRequestFurtherTransitionStages):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
